@@ -18,7 +18,7 @@ use Sub::Exporter -setup =>
 	};
 	
 use vars qw ($VERSION);
-$VERSION     = '0.10';
+$VERSION     = '0.11';
 }
 
 #-------------------------------------------------------------------------------
@@ -46,7 +46,7 @@ use Data::HexDump::Range::Format ;
 
 =head1 NAME
 
-Data::HexDump::Range - Hexadecial Range Dumper with, color, bitfields and skip ranges
+Data::HexDump::Range - Hexadecial Range Dumper with color, bitfields and skip ranges
 
 =head1 SYNOPSIS
 
@@ -239,12 +239,12 @@ Example:
 
 The size field is used to defined if the range is a normal range, a comment, a bitfield or a skip range. The formats are a s follows:
 
-                  format                complete range example
+                  format                          range example
 		  
-  normal range => integer               header, 4, bright_blue     
-  comment      => #                     data section start, # 
-  bitfield     => [xInteger]bInteger    bitfield, x8b4 
-  skip range   => xInteger              boring, x256,, comment
+  normal range => integer                         header, 4, bright_blue
+  comment      => #                               data section start, # 
+  bitfield     => [XInteger][xInteger]bInteger    bitfield, X2x4b4         # X is byte offset, x is bit offset
+  skip range   => xInteger                        boring, X256,, comment
 
 =head3 Coloring
 
@@ -360,12 +360,12 @@ By default bitfields are not displayed  in horizontal mode.
 
 =head3 Skip ranges
 
-If the size format is 'x' + number, that number of bytes is skipped from the data. B<Data::HexDump::Range>
+If the size format is 'X' + number, that number of bytes is skipped from the data. B<Data::HexDump::Range>
 will display the skip range in the dump but not the data.
 
 In the command below, the range 'skip' removes 32 bytes from the display. '>>' is prepended to the range name.
 
-Command: I<hdr -r 'magic cookie, 5   :other,37  :bf,b8   :skip,x32,, I skipped :more, 20'  -rul -col -o ver>
+Command: I<hdr -r 'magic cookie, 5   :other,37  :bf,b8   :skip,X32,, I skipped :more, 20'  -rul -col -o ver>
 
  RANGE_NAME       OFFSET   CUMULATI HEX_DUMP                                         ASCII_DUMP
                                     0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f   0123456789012345
@@ -533,7 +533,7 @@ OR
 
 =head1 EXAMPLES
 
-See I<hdr_examples.pod> in the distribution.
+See L<hdr_examples.pod> in the distribution.
 
 =head1 SUBROUTINES/METHODS
 
@@ -586,9 +586,35 @@ Useful if you use Data::HexDump::Range in an application without terminal.
 
 =item * VERBOSE - Boolean - Display information about the creation of the object. Default is I<false>
 
+=item * DUMP_ORIGINAL_RANGE_DESCRIPTION - Boolean - Diplays the un-processed range descritption.
+
+With B<DUMP_RANGE_DESCRIPTION>, this fields can be used to peek into what range descriptions the module get and how they are
+transformed  into the format that is internally used by the module. These are for debugging purpose and you should normally not need to used them.
+
+ Original range description
+ |- 0 = 'Data'
+ |- 1 = '128'
+ |- 2 = undef
+ `- 3 = undef
+ 
+ Original range description
+ |- 0 = CODE(0x1dc5230)
+ |- 1 = undef
+ |- 2 = undef
+ `- 3 = undef
+
 =item * DUMP_RANGE_DESCRIPTION - Boolean - Diplays the processed range descritption in plain text before the dump
 
-=item * DUMP_ORIGINAL_RANGE_DESCRIPTION - Boolean - Diplays the un-processed range descritption. A debugging flag.
+ 128->26:Data
+ |- COLOR = undef
+ |- DATA = '_blah_blah_blah_blah_blah[\n]'
+ |- IS_BITFIELD = '0'
+ |- IS_COMMENT = '0'
+ |- IS_SKIP = '0'
+ |- NAME = '128->26:Data'
+ |- OFFSET = '20'
+ |- unpack format = 'x20 a26'
+ `- USER_INFORMATION = undef
 
 =item * FORMAT - String - format of the dump string generated by Data::HexDump::Range.
 
